@@ -1,17 +1,24 @@
 import datetime
 import json
-import pytz
-
 from unittest.mock import patch
+
+import pytz
 from requests.exceptions import ConnectionError
+
+from ..exceptions import (
+    TembaBadRequestError,
+    TembaConnectionError,
+    TembaHttpError,
+    TembaNoSuchObjectError,
+    TembaRateExceededError,
+    TembaTokenError,
+)
+from ..tests import MockResponse, TembaTest
 from . import TembaClient
 from .types import Campaign, CampaignEvent, Contact, Field, Flow, Group, Label, Message, ResthookSubscriber
-from ..exceptions import TembaBadRequestError, TembaTokenError, TembaRateExceededError, TembaHttpError
-from ..exceptions import TembaConnectionError
-from ..tests import TembaTest, MockResponse
 
 
-@patch("temba_client.clients.request")
+@patch("temba_client.base.request")
 class TembaClientTest(TembaTest):
     API_VERSION = 2
 
@@ -307,6 +314,29 @@ class TembaClientTest(TembaTest):
             params={"uuid": "09d23a05-47fe-11e4-bfe9-b8f6b119e9ab", "address": "+250788123123"},
         )
 
+    def test_get_classifiers(self, mock_request):
+        # check no params
+        mock_request.return_value = MockResponse(200, self.read_json("classifiers"))
+
+        # check with no params
+        results = self.client.get_classifiers().all()
+
+        self.assertRequest(mock_request, "get", "classifiers")
+        self.assertEqual(len(results), 2)
+
+        self.assertEqual(results[0].uuid, "9a8b001e-a913-486c-80f4-1356e23f582e")
+        self.assertEqual(results[0].type, "wit")
+        self.assertEqual(results[0].name, "Booking")
+        self.assertEqual(results[0].intents, ["book_flight", "book_car"])
+        self.assertEqual(results[0].created_on, datetime.datetime(2015, 6, 8, 12, 18, 7, 671000, pytz.utc))
+
+        # check with all params
+        self.client.get_classifiers(uuid="09d23a05-47fe-11e4-bfe9-b8f6b119e9ab").all()
+
+        self.assertRequest(
+            mock_request, "get", "classifiers", params={"uuid": "09d23a05-47fe-11e4-bfe9-b8f6b119e9ab"}
+        )
+
     def test_get_channel_events(self, mock_request):
         # check no params
         mock_request.return_value = MockResponse(200, self.read_json("channel_events"))
@@ -491,7 +521,7 @@ class TembaClientTest(TembaTest):
         self.assertEqual(results[0].contacts[0].name, "Joe")
         self.assertEqual(results[0].restart_participants, True)
         self.assertEqual(results[0].status, "pending")
-        self.assertEqual(results[0].extra, {"day": "Monday"})
+        self.assertEqual(results[0].params, {"day": "Monday"})
         self.assertEqual(results[0].created_on, datetime.datetime(2015, 8, 26, 10, 4, 9, 737686, pytz.utc))
         self.assertEqual(results[0].modified_on, datetime.datetime(2015, 9, 26, 10, 4, 9, 737686, pytz.utc))
 
@@ -500,6 +530,21 @@ class TembaClientTest(TembaTest):
 
         self.assertRequest(mock_request, "get", "flow_starts", params={"uuid": "93a624ad-5440-415e-b49f-17bf42754acb"})
 
+    def test_get_globals(self, mock_request):
+        # check no params
+        mock_request.return_value = MockResponse(200, self.read_json("globals"))
+
+        # check with no params
+        results = self.client.get_globals().all()
+
+        self.assertRequest(mock_request, "get", "globals")
+        self.assertEqual(len(results), 2)
+
+        self.assertEqual(results[0].key, "org_name")
+        self.assertEqual(results[0].name, "Org Name")
+        self.assertEqual(results[0].value, "Acme Ltd")
+        self.assertEqual(results[0].modified_on, datetime.datetime(2015, 6, 8, 12, 18, 7, 671000, pytz.utc))
+
     def test_get_groups(self, mock_request):
         # check no params
         mock_request.return_value = MockResponse(200, self.read_json("groups"))
@@ -834,7 +879,7 @@ class TembaClientTest(TembaTest):
             groups=["04a4752b-0f49-480e-ae60-3a3f2bea485c"],
             urns=[],
             restart_participants=False,
-            extra={"day": "Monday"},
+            params={"day": "Monday"},
         )
 
         self.assertRequest(
@@ -847,11 +892,18 @@ class TembaClientTest(TembaTest):
                 "groups": ["04a4752b-0f49-480e-ae60-3a3f2bea485c"],
                 "urns": [],
                 "restart_participants": False,
-                "extra": {"day": "Monday"},
+                "params": {"day": "Monday"},
             },
         )
         self.assertEqual(start.uuid, "93a624ad-5440-415e-b49f-17bf42754acb")
 
+    def test_create_global(self, mock_request):
+        mock_request.return_value = MockResponse(201, self.read_json("globals", extract_result=0))
+        glbl = self.client.create_global(name="Org Name", value="Acme Ltd")
+
+        self.assertRequest(mock_request, "post", "globals", data={"name": "Org Name", "value": "Acme Ltd"})
+        self.assertEqual(glbl.key, "org_name")
+
     def test_create_group(self, mock_request):
         mock_request.return_value = MockResponse(201, self.read_json("groups", extract_result=0))
         group = self.client.create_group(name="Reporters")
@@ -977,6 +1029,34 @@ class TembaClientTest(TembaTest):
         )
         self.assertEqual(field.key, "chat_name")
 
+        mock_request.return_value = MockResponse(404, {"detail": "Not found."})
+
+        with self.assertRaises(TembaNoSuchObjectError):
+            self.client.update_field(Field.create(key="chat_name2"), label="Chat Name", value_type="text")
+
+            self.assertRequest(
+                mock_request,
+                "post",
+                "fields",
+                params={"key": "chat_name"},
+                data={"label": "Chat Name", "value_type": "text"},
+            )
+
+    def test_update_global(self, mock_request):
+        mock_request.return_value = MockResponse(201, self.read_json("globals", extract_result=0))
+
+        # check update by key
+        glbl = self.client.update_global("org_name", value="Nyaruka")
+
+        self.assertRequest(
+            mock_request,
+            "post",
+            "globals",
+            params={"key": "org_name"},
+            data={"value": "Nyaruka"},
+        )
+        self.assertEqual(glbl.key, "org_name")
+
     def test_update_group(self, mock_request):
         mock_request.return_value = MockResponse(201, self.read_json("groups", extract_result=0))
 
@@ -1178,7 +1258,7 @@ class TembaClientTest(TembaTest):
         )
 
 
-@patch("temba_client.clients.request")
+@patch("temba_client.base.request")
 class TembaClientVerifyTest(TembaTest):
     def test_verify_false(self, mock_request):
         client = TembaClient("example.com", "12345", verify_ssl=False)
